#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-pragmas-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-pragmas-plugin-1.0.0.0-EnM1k0zxlD9H14zD1NLDUp
key:                  hls-pragmas-plugin-1.0.0.0-EnM1k0zxlD9H14zD1NLDUp
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a134452715f5dd1392377d3e5c72f746
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hls-pragmas-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hls-pragmas-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hls-pragmas-plugin-1.0.0.0
hs-libraries:         HShls-pragmas-plugin-1.0.0.0-EnM1k0zxlD9H14zD1NLDUp
depends:
    base-4.14.2.0 extra-1.7.9-4atxCqewDRnKsFBrL9ak4x
    fuzzy-0.1.0.0-G8Hez7wf78XFxniOIXLqjb
    ghcide-1.4.0.1-5stW1V6MhVBGeCRHZSaIfO
    hls-plugin-api-1.1.0.2-6o7hY0E5YQuCD8G4Bf3t3o
    lens-5.0.1-9j09gzxg2dR5Wmd3U39g28
    lsp-1.2.0.0-JYjHpvPu1SW4k7gGYBb5ES text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

